Skip to contents

This function retrieves the main types from the Oncotree database.

Usage

getOncotreeMainTypes()

Value

A data.table containing the main types from the Oncotree database.

Examples

# Requires internet connection to Oncotree API
if (interactive()) {
  getOncotreeMainTypes()
}