Skip to contents

This function retrieves the tumor types from the Oncotree database.

Usage

getOncotreeTumorTypes()

Value

A data.table containing the tumor types from the Oncotree database.

Examples

# Requires internet connection to Oncotree API
if (interactive()) {
  getOncotreeTumorTypes()
}