This function retrieves the main types from the Oncotree database.
Examples
# Requires internet connection to Oncotree API
if (interactive()) {
getOncotreeMainTypes()
}
This function retrieves the main types from the Oncotree database.
# Requires internet connection to Oncotree API
if (interactive()) {
getOncotreeMainTypes()
}