This function retrieves the tumor types from the Oncotree database.
Examples
# Requires internet connection to Oncotree API
if (interactive()) {
getOncotreeTumorTypes()
}
This function retrieves the tumor types from the Oncotree database.
# Requires internet connection to Oncotree API
if (interactive()) {
getOncotreeTumorTypes()
}